# Haimgard-Framework
Haimgard is an environment for writing, testing and using exploit code.

# Reminder
Important Information and Reminder Information and programs in all repositories are created for testing purposes. Any legal responsibility belongs to the person or organization that uses it.